==> openshift-model-miscellaneous-5.12.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/RootDeviceHintsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RootDeviceHintsBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsBuilder>{
  public RootDeviceHintsBuilder() {
    this(false);
  }
  public RootDeviceHintsBuilder(java.lang.Boolean validationEnabled) {
    this(new RootDeviceHints(), validationEnabled);
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluent<?> fluent) {
    this(fluent, false);
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RootDeviceHints(), validationEnabled);
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints instance) {
    this(fluent, instance, false);
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDeviceName(instance.getDeviceName()); 
    fluent.withHctl(instance.getHctl()); 
    fluent.withMinSizeGigabytes(instance.getMinSizeGigabytes()); 
    fluent.withModel(instance.getModel()); 
    fluent.withRotational(instance.getRotational()); 
    fluent.withSerialNumber(instance.getSerialNumber()); 
    fluent.withVendor(instance.getVendor()); 
    fluent.withWwn(instance.getWwn()); 
    fluent.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    fluent.withWwnWithExtension(instance.getWwnWithExtension()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints instance) {
    this(instance,false);
  }
  public RootDeviceHintsBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDeviceName(instance.getDeviceName()); 
    this.withHctl(instance.getHctl()); 
    this.withMinSizeGigabytes(instance.getMinSizeGigabytes()); 
    this.withModel(instance.getModel()); 
    this.withRotational(instance.getRotational()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withVendor(instance.getVendor()); 
    this.withWwn(instance.getWwn()); 
    this.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    this.withWwnWithExtension(instance.getWwnWithExtension()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHintsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.RootDeviceHints build() {
    RootDeviceHints buildable = new RootDeviceHints(fluent.getDeviceName(),fluent.getHctl(),fluent.getMinSizeGigabytes(),fluent.getModel(),fluent.getRotational(),fluent.getSerialNumber(),fluent.getVendor(),fluent.getWwn(),fluent.getWwnVendorExtension(),fluent.getWwnWithExtension());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RootDeviceHintsBuilder that = (RootDeviceHintsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/RootDeviceHintsBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RootDeviceHintsBuilder extends RootDeviceHintsFluentImpl<RootDeviceHintsBuilder> implements VisitableBuilder<RootDeviceHints,RootDeviceHintsBuilder>{
  public RootDeviceHintsBuilder() {
    this(false);
  }
  public RootDeviceHintsBuilder(Boolean validationEnabled) {
    this(new RootDeviceHints(), validationEnabled);
  }
  public RootDeviceHintsBuilder(RootDeviceHintsFluent<?> fluent) {
    this(fluent, false);
  }
  public RootDeviceHintsBuilder(RootDeviceHintsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RootDeviceHints(), validationEnabled);
  }
  public RootDeviceHintsBuilder(RootDeviceHintsFluent<?> fluent,RootDeviceHints instance) {
    this(fluent, instance, false);
  }
  public RootDeviceHintsBuilder(RootDeviceHintsFluent<?> fluent,RootDeviceHints instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDeviceName(instance.getDeviceName()); 
    fluent.withHctl(instance.getHctl()); 
    fluent.withMinSizeGigabytes(instance.getMinSizeGigabytes()); 
    fluent.withModel(instance.getModel()); 
    fluent.withRotational(instance.getRotational()); 
    fluent.withSerialNumber(instance.getSerialNumber()); 
    fluent.withVendor(instance.getVendor()); 
    fluent.withWwn(instance.getWwn()); 
    fluent.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    fluent.withWwnWithExtension(instance.getWwnWithExtension()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public RootDeviceHintsBuilder(RootDeviceHints instance) {
    this(instance,false);
  }
  public RootDeviceHintsBuilder(RootDeviceHints instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDeviceName(instance.getDeviceName()); 
    this.withHctl(instance.getHctl()); 
    this.withMinSizeGigabytes(instance.getMinSizeGigabytes()); 
    this.withModel(instance.getModel()); 
    this.withRotational(instance.getRotational()); 
    this.withSerialNumber(instance.getSerialNumber()); 
    this.withVendor(instance.getVendor()); 
    this.withWwn(instance.getWwn()); 
    this.withWwnVendorExtension(instance.getWwnVendorExtension()); 
    this.withWwnWithExtension(instance.getWwnWithExtension()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  RootDeviceHintsFluent<?> fluent;
  Boolean validationEnabled;
  public RootDeviceHints build() {
    RootDeviceHints buildable = new RootDeviceHints(fluent.getDeviceName(),fluent.getHctl(),fluent.getMinSizeGigabytes(),fluent.getModel(),fluent.getRotational(),fluent.getSerialNumber(),fluent.getVendor(),fluent.getWwn(),fluent.getWwnVendorExtension(),fluent.getWwnWithExtension());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
